@@ -52,14 +52,14 @@ extern SbkConverter **SbkPySide6_QtNetworkAuthTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTNETWORKAUTH_QLIST_INT_IDX                          = 0, // QList<int >
-    SBK_QTNETWORKAUTH_QMAP_QSTRING_QVARIANT_IDX              = 1, // QMap<QString,QVariant >
-    SBK_QTNETWORKAUTH_QLIST_QOBJECTPTR_IDX                   = 2, // QList<QObject* >
-    SBK_QTNETWORKAUTH_QLIST_QBYTEARRAY_IDX                   = 3, // QList<QByteArray >
-    SBK_QTNETWORKAUTH_QMULTIMAP_QSTRING_QVARIANT_IDX         = 4, // QMultiMap<QString,QVariant >
-    SBK_QTNETWORKAUTH_QPAIR_QSTRING_QSTRING_IDX              = 5, // QPair<QString,QString >
-    SBK_QTNETWORKAUTH_QLIST_QSTRING_IDX                      = 6, // QList<QString >
-    SBK_QTNETWORKAUTH_QLIST_QVARIANT_IDX                     = 7, // QList<QVariant >
+    SBK_QTNETWORKAUTH_QLIST_INT_IDX                          = 0, // QList<int>
+    SBK_QTNETWORKAUTH_QMAP_QSTRING_QVARIANT_IDX              = 1, // QMap<QString,QVariant>
+    SBK_QTNETWORKAUTH_QLIST_QOBJECTPTR_IDX                   = 2, // QList<QObject*>
+    SBK_QTNETWORKAUTH_QLIST_QBYTEARRAY_IDX                   = 3, // QList<QByteArray>
+    SBK_QTNETWORKAUTH_QMULTIMAP_QSTRING_QVARIANT_IDX         = 4, // QMultiMap<QString,QVariant>
+    SBK_QTNETWORKAUTH_STD_PAIR_QSTRING_QSTRING_IDX           = 5, // std::pair<QString,QString>
+    SBK_QTNETWORKAUTH_QLIST_QSTRING_IDX                      = 6, // QList<QString>
+    SBK_QTNETWORKAUTH_QLIST_QVARIANT_IDX                     = 7, // QList<QVariant>
     SBK_QtNetworkAuth_CONVERTERS_IDX_COUNT                   = 8
 };
 // Macros for type check
